@@ -540,7 +540,7 @@ class RevisionsTableView(ActionsMixin, StyledTableView, SmartResizeTableView):
             rev = rev.split(':')[1]
         repo = self.model().repo
         try:
-            rev = repo.changectx(rev).rev()
+            rev = repo[rev].rev()
         except RepoError:
             self.message_logged.emit(
                       "Can't find revision '%s'" % rev, 2000)
